@@ -225,12 +225,32 @@ from ncbi.datasets.openapi.model.v1_warning_gene_warning_code import V1WarningGe
 from ncbi.datasets.openapi.model.v1_warning_gene_warning_code import V1WarningGeneWarningCode as V1alpha1WarningGeneWarningCode
 from ncbi.datasets.openapi.model.v1_warning_replaced_id import V1WarningReplacedId
 from ncbi.datasets.openapi.model.v1_warning_replaced_id import V1WarningReplacedId as V1alpha1WarningReplacedId
+from ncbi.datasets.openapi.model.v1reports_bio_project import V1reportsBioProject
+from ncbi.datasets.openapi.model.v1reports_bio_project import V1reportsBioProject as V1alpha1reportsBioProject
+from ncbi.datasets.openapi.model.v1reports_bio_sample_attribute import V1reportsBioSampleAttribute
+from ncbi.datasets.openapi.model.v1reports_bio_sample_attribute import V1reportsBioSampleAttribute as V1alpha1reportsBioSampleAttribute
+from ncbi.datasets.openapi.model.v1reports_bio_sample_contact import V1reportsBioSampleContact
+from ncbi.datasets.openapi.model.v1reports_bio_sample_contact import V1reportsBioSampleContact as V1alpha1reportsBioSampleContact
+from ncbi.datasets.openapi.model.v1reports_bio_sample_description import V1reportsBioSampleDescription
+from ncbi.datasets.openapi.model.v1reports_bio_sample_description import V1reportsBioSampleDescription as V1alpha1reportsBioSampleDescription
+from ncbi.datasets.openapi.model.v1reports_bio_sample_descriptor import V1reportsBioSampleDescriptor
+from ncbi.datasets.openapi.model.v1reports_bio_sample_descriptor import V1reportsBioSampleDescriptor as V1alpha1reportsBioSampleDescriptor
+from ncbi.datasets.openapi.model.v1reports_bio_sample_id import V1reportsBioSampleId
+from ncbi.datasets.openapi.model.v1reports_bio_sample_id import V1reportsBioSampleId as V1alpha1reportsBioSampleId
+from ncbi.datasets.openapi.model.v1reports_bio_sample_owner import V1reportsBioSampleOwner
+from ncbi.datasets.openapi.model.v1reports_bio_sample_owner import V1reportsBioSampleOwner as V1alpha1reportsBioSampleOwner
+from ncbi.datasets.openapi.model.v1reports_bio_sample_status import V1reportsBioSampleStatus
+from ncbi.datasets.openapi.model.v1reports_bio_sample_status import V1reportsBioSampleStatus as V1alpha1reportsBioSampleStatus
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_gene_type import V1reportsGeneDescriptorGeneType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_gene_type import V1reportsGeneDescriptorGeneType as V1alpha1reportsGeneDescriptorGeneType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_rna_type import V1reportsGeneDescriptorRnaType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_rna_type import V1reportsGeneDescriptorRnaType as V1alpha1reportsGeneDescriptorRnaType
 from ncbi.datasets.openapi.model.v1reports_genomic_region_genomic_region_type import V1reportsGenomicRegionGenomicRegionType
 from ncbi.datasets.openapi.model.v1reports_genomic_region_genomic_region_type import V1reportsGenomicRegionGenomicRegionType as V1alpha1reportsGenomicRegionGenomicRegionType
+from ncbi.datasets.openapi.model.v1reports_lineage_organism import V1reportsLineageOrganism
+from ncbi.datasets.openapi.model.v1reports_lineage_organism import V1reportsLineageOrganism as V1alpha1reportsLineageOrganism
+from ncbi.datasets.openapi.model.v1reports_organism import V1reportsOrganism
+from ncbi.datasets.openapi.model.v1reports_organism import V1reportsOrganism as V1alpha1reportsOrganism
 from ncbi.datasets.openapi.model.v1reports_orientation import V1reportsOrientation
 from ncbi.datasets.openapi.model.v1reports_orientation import V1reportsOrientation as V1alpha1reportsOrientation
 from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_completeness import V1reportsProkaryoteGeneLocationCompleteness
